pub struct ExtendedKeyUsage(pub Vec<ObjectIdentifier>);Expand description
ExtKeyUsageSyntax as defined in RFC 5280 Section 4.2.1.12.
Many extended key usage values include:
PKIX_CE_ANYEXTENDEDKEYUSAGE,PKIX_KP_SERVERAUTH,PKIX_KP_CLIENTAUTH,PKIX_KP_CODESIGNING,PKIX_KP_EMAILPROTECTION,PKIX_KP_TIMESTAMPING,
ExtKeyUsageSyntax ::= SEQUENCE SIZE (1..MAX) OF KeyPurposeId
KeyPurposeId ::= OBJECT IDENTIFIERTuple Fields
0: Vec<ObjectIdentifier>Trait Implementations
Sourceimpl<'a> AsMut<Vec<ObjectIdentifier>> for ExtendedKeyUsage
impl<'a> AsMut<Vec<ObjectIdentifier>> for ExtendedKeyUsage
Sourcefn as_mut(&mut self) -> &mut Vec<ObjectIdentifier>
fn as_mut(&mut self) -> &mut Vec<ObjectIdentifier>
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl<'a> AsRef<Vec<ObjectIdentifier>> for ExtendedKeyUsage
impl<'a> AsRef<Vec<ObjectIdentifier>> for ExtendedKeyUsage
Sourcefn as_ref(&self) -> &Vec<ObjectIdentifier>
fn as_ref(&self) -> &Vec<ObjectIdentifier>
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl AssociatedOid for ExtendedKeyUsage
impl AssociatedOid for ExtendedKeyUsage
Sourceconst OID: ObjectIdentifier = ID_CE_EXT_KEY_USAGE
const OID: ObjectIdentifier = ID_CE_EXT_KEY_USAGE
The OID associated with this type.
Sourceimpl Clone for ExtendedKeyUsage
impl Clone for ExtendedKeyUsage
Sourcefn clone(&self) -> ExtendedKeyUsage
fn clone(&self) -> ExtendedKeyUsage
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Criticality for ExtendedKeyUsage
impl Criticality for ExtendedKeyUsage
Sourceimpl Debug for ExtendedKeyUsage
impl Debug for ExtendedKeyUsage
Sourceimpl<'a> DecodeValue<'a> for ExtendedKeyUsage
impl<'a> DecodeValue<'a> for ExtendedKeyUsage
Sourceimpl<'a> EncodeValue for ExtendedKeyUsage
impl<'a> EncodeValue for ExtendedKeyUsage
impl Eq for ExtendedKeyUsage
Sourceimpl<'a> FixedTag for ExtendedKeyUsage
impl<'a> FixedTag for ExtendedKeyUsage
Sourceimpl<'a> From<Vec<ObjectIdentifier>> for ExtendedKeyUsage
impl<'a> From<Vec<ObjectIdentifier>> for ExtendedKeyUsage
Sourcefn from(value: Vec<ObjectIdentifier>) -> ExtendedKeyUsage
fn from(value: Vec<ObjectIdentifier>) -> ExtendedKeyUsage
Converts to this type from the input type.
Sourceimpl PartialEq for ExtendedKeyUsage
impl PartialEq for ExtendedKeyUsage
impl StructuralPartialEq for ExtendedKeyUsage