pub struct SubjectAltName(pub Vec<GeneralName>);Expand description
SubjectAltName as defined in RFC 5280 Section 4.2.1.6.
SubjectAltName ::= GeneralNamesTuple Fields
0: Vec<GeneralName>Trait Implementations
Sourceimpl<'a> AsMut<Vec<GeneralName>> for SubjectAltName
impl<'a> AsMut<Vec<GeneralName>> for SubjectAltName
Sourcefn as_mut(&mut self) -> &mut Vec<GeneralName>
fn as_mut(&mut self) -> &mut Vec<GeneralName>
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl<'a> AsRef<Vec<GeneralName>> for SubjectAltName
impl<'a> AsRef<Vec<GeneralName>> for SubjectAltName
Sourcefn as_ref(&self) -> &Vec<GeneralName>
fn as_ref(&self) -> &Vec<GeneralName>
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl AssociatedOid for SubjectAltName
impl AssociatedOid for SubjectAltName
Sourceconst OID: ObjectIdentifier = ID_CE_SUBJECT_ALT_NAME
const OID: ObjectIdentifier = ID_CE_SUBJECT_ALT_NAME
The OID associated with this type.
Sourceimpl Clone for SubjectAltName
impl Clone for SubjectAltName
Sourcefn clone(&self) -> SubjectAltName
fn clone(&self) -> SubjectAltName
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Criticality for SubjectAltName
impl Criticality for SubjectAltName
Sourceimpl Debug for SubjectAltName
impl Debug for SubjectAltName
Sourceimpl<'a> DecodeValue<'a> for SubjectAltName
impl<'a> DecodeValue<'a> for SubjectAltName
Sourceimpl Default for SubjectAltName
impl Default for SubjectAltName
Sourcefn default() -> SubjectAltName
fn default() -> SubjectAltName
Returns the “default value” for a type. Read more
Sourceimpl<'a> EncodeValue for SubjectAltName
impl<'a> EncodeValue for SubjectAltName
impl Eq for SubjectAltName
Sourceimpl<'a> FixedTag for SubjectAltName
impl<'a> FixedTag for SubjectAltName
Sourceimpl<'a> From<Vec<GeneralName>> for SubjectAltName
impl<'a> From<Vec<GeneralName>> for SubjectAltName
Sourcefn from(value: Vec<GeneralName>) -> SubjectAltName
fn from(value: Vec<GeneralName>) -> SubjectAltName
Converts to this type from the input type.
Sourceimpl PartialEq for SubjectAltName
impl PartialEq for SubjectAltName
impl StructuralPartialEq for SubjectAltName