pub struct SubjectAltName(pub Vec<GeneralName>);Expand description
SubjectAltName as defined in RFC 5280 Section 4.2.1.6.
SubjectAltName ::= GeneralNamesTuple Fields
0: Vec<GeneralName>Trait Implementations
Sourceimpl AsExtension for SubjectAltName
impl AsExtension for SubjectAltName
Sourcefn critical(&self, subject: &RdnSequence, _extensions: &[Extension]) -> bool
fn critical(&self, subject: &RdnSequence, _extensions: &[Extension]) -> bool
Should the extension be marked critical
Sourcefn to_extension(
&self,
subject: &RdnSequence,
extensions: &[Extension],
) -> Result<Extension, Error>
fn to_extension( &self, subject: &RdnSequence, extensions: &[Extension], ) -> Result<Extension, Error>
Returns the Extension with the content encoded.
Sourceimpl<'a> AsMut<Vec<GeneralName>> for SubjectAltName
impl<'a> AsMut<Vec<GeneralName>> for SubjectAltName
Sourcefn as_mut(&mut self) -> &mut Vec<GeneralName>
fn as_mut(&mut self) -> &mut Vec<GeneralName>
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl<'a> AsRef<Vec<GeneralName>> for SubjectAltName
impl<'a> AsRef<Vec<GeneralName>> for SubjectAltName
Sourcefn as_ref(&self) -> &Vec<GeneralName>
fn as_ref(&self) -> &Vec<GeneralName>
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl AssociatedOid for SubjectAltName
impl AssociatedOid for SubjectAltName
Sourceconst OID: ObjectIdentifier = ID_CE_SUBJECT_ALT_NAME
const OID: ObjectIdentifier = ID_CE_SUBJECT_ALT_NAME
The OID associated with this type.
Sourceimpl Clone for SubjectAltName
impl Clone for SubjectAltName
Sourcefn clone(&self) -> SubjectAltName
fn clone(&self) -> SubjectAltName
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SubjectAltName
impl Debug for SubjectAltName
Sourceimpl<'a> DecodeValue<'a> for SubjectAltName
impl<'a> DecodeValue<'a> for SubjectAltName
Sourcefn decode_value<R>(
decoder: &mut R,
header: Header,
) -> Result<SubjectAltName, Error>where
R: Reader<'a>,
fn decode_value<R>(
decoder: &mut R,
header: Header,
) -> Result<SubjectAltName, Error>where
R: Reader<'a>,
Attempt to decode this message using the provided
Reader.Sourceimpl Default for SubjectAltName
impl Default for SubjectAltName
Sourcefn default() -> SubjectAltName
fn default() -> SubjectAltName
Returns the “default value” for a type. Read more
Sourceimpl<'a> EncodeValue for SubjectAltName
impl<'a> EncodeValue for SubjectAltName
Sourceimpl<'a> FixedTag for SubjectAltName
impl<'a> FixedTag for SubjectAltName
Sourceimpl<'a> From<SubjectAltName> for Vec<GeneralName>
impl<'a> From<SubjectAltName> for Vec<GeneralName>
Sourcefn from(value: SubjectAltName) -> Vec<GeneralName>
fn from(value: SubjectAltName) -> Vec<GeneralName>
Converts to this type from the input type.
Sourceimpl<'a> From<Vec<GeneralName>> for SubjectAltName
impl<'a> From<Vec<GeneralName>> for SubjectAltName
Sourcefn from(value: Vec<GeneralName>) -> SubjectAltName
fn from(value: Vec<GeneralName>) -> SubjectAltName
Converts to this type from the input type.
Sourceimpl PartialEq for SubjectAltName
impl PartialEq for SubjectAltName
Sourceimpl<'a> ValueOrd for SubjectAltName
impl<'a> ValueOrd for SubjectAltName
impl Eq for SubjectAltName
impl StructuralPartialEq for SubjectAltName